@@ -34,12 +34,22 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
   # sector <- "TOTAL"
   # importer <- "WLD"
 
+
   method <- exvadec$method
   output <- exvadec$output
 
-  df <- dbva[dbva$method == method & dbva$output == output, ]
 
-  term <- 0
+  # Carriage return
+  cr <- "\n"
+
+
+  # *********************
+  # TABLE WITH DATA----
+  # *********************
+
+  # Extract indicators for specified method and output
+  # from database
+  df <- dbva[dbva$method == method & dbva$output == output, ]
 
   # Get total exports
   EXGR <- get_data(exvadec,  var = "EXGR", exporter = exporter,
@@ -47,8 +57,11 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
 
   # Create a basic data frame with three columns:
   # id code, level and description
+
+  # Initialize
   row_labels <- NULL
   tbl_values <- NULL
+  term <- 0
   for (i in seq_along(df[["id"]])){
 
     var_code <- df[i, ][["id"]]
@@ -62,15 +75,15 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
     valuesh <- round(100 * value/EXGR, 2)
 
     # Text will depend on the type of output
-    # Standard will show   XXXXXXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
-    # Terms will show      T01 XXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
-    # Full or TiVA show    XXXXXXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
-    if (output %in% c("standard", "tiva")) {
+    # basic/Standard show   XXXXXXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
+    # Terms will show       T01 XXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
+    # Full or TiVA show     XXXXXXXXXXXXXXXXX (XXX)  XXX.XX  XX.XX
+    if (output %in% c("basic", "standard", "tiva")) {
 
       var_name <- paste0(spc(var_level, 2), var_txt, " (", var_code, ")")
 
     } else if (output %in% c("terms", "terms2")){
-
+      # Add term X to every terms (except EGR)
       if (!var_code == "EXGR"){
         term <- term + 1
         var_name <- paste0(spc(var_level, 2), "T", sprintf("%02d", term),
@@ -78,7 +91,6 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
       } else{
         var_name <- paste0(var_code, " (", var_txt, ")")
       }
-
     }
 
     row_labels <- c(row_labels, var_name)
@@ -86,6 +98,19 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
 
   }
 
+  # Capture data
+  tbl <- data.frame("VA_components" = row_labels,
+                    "USD_MM" = tbl_values[,1],
+                    "Percent"= tbl_values[,2])
+  tbl_txt <- utils::capture.output(print(tbl, row.names = FALSE,
+                                         quote = FALSE, right = FALSE))
+  tbl_txt <- paste0(tbl_txt, collapse = cr)
+
+
+  # *********************
+  # HEADER: EXPORTER----
+  # *********************
+
   # Text for exporter (in title)
   if (all(is.null(exvadec$exporter), exporter == "WLD")) {
     txt_exporter <- "All countries"
@@ -95,8 +120,13 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
     txt_exporter <- dbgeo[dbgeo$id == exporter, ][["txt_en"]]
   }
 
+  # If not found, just use the variable exporter (ej. C01 in custom)
   if (length(txt_exporter) == 0) {txt_exporter <- exporter}
 
+  # *******************
+  # HEADER: SECTOR----
+  # *******************
+
   # Text for sector
   if (sector == "TOTAL") {
     txt_sector <- "All sectors"
@@ -105,11 +135,11 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
                          " (", sector, ")")
   }
 
-  # Special case, if Miroudot and Ye (2021)
+  # Special case, if Borin and Mancini (2019) or Miroudot and Ye (2021)
   # If there is an element called "sector" in exvadec then
-  # it is a my decomposition
+  # it is a BM/MY decomposition
   if (exists("sector", exvadec)) {
-    # If sector is not TOTAL, use partner code as importer
+    # If sector is not TOTAL, use sector code as sector
     if (!exvadec$sector == "TOTAL") {
       txt_sector <-
         paste0(dbsec[dbsec$id == exvadec$sector, ][["txt_short_en"]],
@@ -117,6 +147,10 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
     }
   }
 
+  # ******************
+  # HEADER: IMPORTER----
+  # *****************
+
   # Text for importer
   if (importer == "WLD") {
     txt_importer <- "All countries"
@@ -125,9 +159,9 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
                            " (", importer, ")")
   }
 
-  # Special case, if Miroudot and Ye (2021)
+  # Special case, if Borin and Mancini (2019) or Miroudot and Ye (2021)
   # If there is an element called "partner" in exvadec then
-  # it is a my decomposition
+  # it is a BM/MY decomposition
   if (exists("partner", exvadec)) {
     # If partner is not WLD, use partner code as importer
     if (!exvadec$partner == "WLD") {
@@ -139,15 +173,9 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
 
 
 
-  # Text for data
-  cr <- "\n"
-
-  tbl <- data.frame("VA_components" = row_labels,
-                    "USD_MM" = tbl_values[,1],
-                    "Percent"= tbl_values[,2])
-  tbl_txt <- utils::capture.output(print(tbl, row.names = FALSE,
-                                         quote = FALSE, right = FALSE))
-  tbl_txt <- paste0(tbl_txt, collapse = cr)
+  # **********************
+  # FOOTNOTE: METHOD ----
+  # **********************
 
   # Text for decomposition method
 
@@ -156,28 +184,35 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
             dbmet$output == exvadec$output, ][["txt_en"]]
 
 
+  # ***********************************
+  # FOOTNOTE: PERSPECTIVE AND APPROACH
+  # ***********************************
+
   # Text for perspective and approach
+
   # Perspective
-  if (exvadec$method == "my") {
-    if (!exvadec$perim == "country") {
+
+  if (exvadec$method %in% c("bm_src", "my")) {
+    # Default
+    persp_txt <- "Country perspective"
+    if (all(exvadec$method == "my", exvadec$perim == "WLD")) {
       persp_txt <- "World perspective"
-    } else {
-      if (all(exvadec$partner == "WLD", exvadec$sector == "TOTAL")) {
-        persp_txt <- "Country perspective"
-      } else if (all(!exvadec$partner == "WLD", exvadec$sector == "TOTAL")) {
-        persp_txt <- paste0("Bilateral perspective (",
-                            exvadec$partner, ")")
-      } else if (all(exvadec$partner == "WLD", !exvadec$sector == "TOTAL")) {
-        persp_txt <- paste0("Sector perspective (",
-                            exvadec$sector, ")")
-      } else if (all(!exvadec$partner == "WLD", !exvadec$sector == "TOTAL")) {
-        persp_txt <- paste0("Bilateral-sector perspective (",
-                            exvadec$partner, "-",
-                            exvadec$sector, ")")
-      }
+    }
+    # If exists partner or sector
+    if (all(exists("partner", exvadec), !exists("sector", exvadec))) {
+      persp_txt <- paste0("Bilateral perspective (",
+                          exvadec$partner, ")")
+    } else if (all(!exists("partner", exvadec), exists("sector", exvadec))) {
+      persp_txt <- paste0("Sector perspective (",
+                          exvadec$sector, ")")
+    } else if (all(exists("partner", exvadec), exists("sector", exvadec))) {
+      persp_txt <- paste0("Bilateral-sector perspective (",
+                          exvadec$partner, "-",
+                          exvadec$sector, ")")
     }
   } else if (exvadec$method %in% c("kww", "wwz")) {
     persp_txt <- "Mix of country and world perspective"
+    # Else (oecd, bm_sink)
   } else {
     persp_txt <- "Country perspective"
   }
@@ -191,40 +226,42 @@ get_exvadec_bkdown <- function(exvadec_object, exporter = "WLD",
     appr_txt <- "mix of source and sink approach"
   }
 
+  # *********************
+  # FOOTNOTE: PRINT----
+  # *********************
+
   # Start printing
 
-  # Use cr for \n
-  cr <- "\n"
-
   # Start header
-  # txt <- paste0("Done!", cr)
   txt <- paste0(hline(), cr)
 
   title <- center(paste0("DECOMPOSITION OF VALUE ADDED IN EXPORTS OF ",
                   toupper(txt_exporter), " IN ", exvadec$year))
 
   txt <- paste0(txt, title, cr)
-  txt <- paste0(txt, spc(20), "Sector: ", txt_sector, cr)
-  txt <- paste0(txt, spc(20), "Destination: ", txt_importer, cr)
+  txt <- paste0(txt, spc(15), "Sector: ", txt_sector, cr)
+  txt <- paste0(txt, spc(15), "Destination: ", txt_importer, cr)
   txt <- paste0(txt, hline(), cr)
   # End header
 
-  # Table
+  # Start table
   txt <- paste0(txt, tbl_txt, cr)
   txt <- paste0(txt, hline(), cr)
+  # End table
 
-  # Table footnote
+  # Start footnote
   txt <- paste0(txt, "Method: ", method_txt, cr)
   txt <- paste0(txt, persp_txt, ", ", appr_txt, cr)
-
+  # End footnote
 
   # End of text
 
   # Print text to console
-  # cli::cli_alert_success(txt)
+  # cli::cli_alert_success(txt) incompatible with Sweave
+  # so we use cat
   cat(txt)
 
-  # Return tbl (without printing to console)
+  # Return tbl (without double printing to console)
   return(invisible(tbl))
 
 }
